@@ -194,18 +194,25 @@ the following order:
     :meth:`~MainAppBase.stop_app` method.
 
 
-application state change events
-_______________________________
+application state change and save events
+________________________________________
 
 Notification events get fired when one of the app state variables
 gets changed - like e.g. the :ref:`application flow` or if
 the user changes the font size.
 
-The method name of the notification event consists of
+The method name of the app state change notification event consists of
 the prefix ``on_`` followed by the variable name of the app state.
 So e.g. on a change of the `font_size` app state the notification
 event `on_font_size` will be fired/called (if exists as a method
-of the main app instance).
+of the main app instance). These events don't provide any
+event arguments.
+
+Another app state event gets fired after the app states getting
+retrieved from the app class instance and before they get saved.
+This event has the method name :meth:`on_app_states_save` and
+provides one event argument `app_states` which is a dict of
+type :data:`AppStateType` containing all app states.
 
 
 application flow change events
@@ -369,7 +376,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.23'
+__version__ = '0.0.24'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -638,6 +645,9 @@ class MainAppBase(ConsoleApp, ABC):
         err_msg = ""
 
         app_state = self.retrieve_app_states()
+
+        self.call_method('on_app_states_save', app_state)
+
         for key, state in app_state.items():
             if key == 'flow_id' and flow_action(state) != 'focus':
                 state = id_of_flow('', '')
